/**
 * Copyright 2012 Cloudera Inc.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudera.hadoop.hdfs.nfs.nfs4.requests;

import static com.cloudera.hadoop.hdfs.nfs.nfs4.Constants.*;

import com.cloudera.hadoop.hdfs.nfs.nfs4.Bitmap;
import com.cloudera.hadoop.hdfs.nfs.nfs4.OpaqueData8;
import com.cloudera.hadoop.hdfs.nfs.rpc.RPCBuffer;


public class READDIRRequest extends OperationRequest {
  protected long mCookie;
  protected OpaqueData8 mCookieVerifer;
  protected int mDirCount;
  protected int mMaxCount;
  protected Bitmap mAttrs;
  public Bitmap getAttrs() {
    return mAttrs;
  }

  public long getCookie() {
    return mCookie;
  }

  public OpaqueData8 getCookieVerifer() {
    return mCookieVerifer;
  }

  public int getDirCount() {
    return mDirCount;
  }

  @Override
  public int getID() {
    return NFS4_OP_READDIR;
  }

  public int getMaxCount() {
    return mMaxCount;
  }

  @Override
  public void read(RPCBuffer buffer) {
    mCookie = buffer.readUint64();
    mCookieVerifer = new OpaqueData8();
    mCookieVerifer.read(buffer);
    mDirCount = buffer.readUint32();
    mMaxCount = buffer.readUint32();
    mAttrs = new Bitmap();
    mAttrs.read(buffer);
  }

  public void setAttrs(Bitmap attrs) {
    this.mAttrs = attrs;
  }

  public void setCookie(long cookie) {
    this.mCookie = cookie;
  }

  public void setCookieVerifer(OpaqueData8 cookieVerifer) {
    this.mCookieVerifer = cookieVerifer;
  }

  public void setDirCount(int dirCount) {
    this.mDirCount = dirCount;
  }

  public void setMaxCount(int maxCount) {
    this.mMaxCount = maxCount;
  }

  @Override
  public void write(RPCBuffer buffer) {
    buffer.writeUint64(mCookie);
    mCookieVerifer.write(buffer);
    buffer.writeUint32(mDirCount);
    buffer.writeUint32(mMaxCount);
    mAttrs.write(buffer);
  }

}
